Learn R Programming

dmm (version 2.1-3)

print.gresponse.dmm: Print method for object of class gresponse.dmm.

Description

Prints overall responses only.

Usage

# S3 method for gresponse.dmm
print(x, ...)

Arguments

x

An object of class gresponse.dmm.

...

Ellipsis argumnet.

Value

There is no return value. Function is used for its side effects.

Details

This is a simple printout of overall response estimates. There are no standard errors or confidence limits for response estimates.

See Also

Functions gresponse.dmm(), summary.gresponse.dmm().

Examples

Run this code
# NOT RUN {
library(dmm)
data(sheep.df)
sheep.mdf <- mdf(sheep.df,pedcols=c(1:3),factorcols=c(4:6),ycols=c(7:9),
             sexcode=c("M","F"),relmat=c("E","A"))
# make a simple fit object - OLS-b only
sheep.fit1 <- dmm(sheep.mdf, Ymat ~ 1 + Year + Sex)
# compute some response estimates, use all the defaults
sheep.resp <- gresponse(sheep.fit1,psd=list(dp=c(1,1,1)))
# print these
print(sheep.resp)
# }
# NOT RUN {
# can do the same thing without saving response object
gresponse(sheep.fit1,psd=list(dp=c(1,1,1)))
# so this is the default print method for an object of class 'gresponse.dmm'
# }
# NOT RUN {
#cleanup
rm(sheep.fit1)
rm(sheep.resp)
rm(sheep.mdf)
rm(sheep.df)
# }

Run the code above in your browser using DataLab