Learn R Programming

dmm (version 2.1-3)

print.gsummary.dmm: Print method for object of class gsummary.dmm.

Description

Formats each attribute of a gsummary.dmm object for printing, adding appropriate headings.

Usage

# S3 method for gsummary.dmm
print(x, ...)

Arguments

x

An object of class gsummary.dmm.

...

Ellipsis argument

Value

There is no return value. Function is used for its side effects.

Details

Each table in an object of class gsummary.dmm is a dataframe. This method uses the default dataframe print method to format each table for printing, passing the digits attribute from the gsummary.dmm object to the print call.

See Also

Function gsummary.dmm().

Examples

Run this code
# NOT RUN {
library(dmm)
data(sheep.df)
sheep.mdf <- mdf(sheep.df,pedcols=c(1:3),factorcols=c(4:6),ycols=c(7:9),
             sexcode=c("M","F"),relmat=c("E","A"))
# make a simple fit object - OLS-b only
sheep.fit1 <- dmm(sheep.mdf, Ymat ~ 1 + Year + Sex)
# compute a 'gsummary.dmm' object, use all the defaults
sheep.gsum <- gsummary(sheep.fit1)
# print the summary of genetic parameters
print(sheep.gsum)
# }
# NOT RUN {
# can do the same thing without saving response object
gsummary(sheep.fit1)
# so this is the default print method for an object of class 'gsummary.dmm'
# }
# NOT RUN {
#cleanup
rm(sheep.fit1)
rm(sheep.gsum)
rm(sheep.mdf)
rm(sheep.df)
# }

Run the code above in your browser using DataLab